#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_THIRD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_THIRD_HPP_INCLUDED

#include <boost/simd/constant/include/constants/third.hpp>

#endif
